# emyo


[![image](https://img.shields.io/pypi/v/emyo.svg)](https://pypi.python.org/pypi/emyo)
[![image](https://img.shields.io/conda/vn/conda-forge/emyo.svg)](https://anaconda.org/conda-forge/emyo)


**An interactive map for children**


-   Free software: MIT license
-   Documentation: https://geofixit.github.io/emyo
    

## Features

-   TODO
